#!/usr/bin/env python
# coding: utf-8

# In[ ]:

import pandas as pd
import numpy as np

def preprocess_data(df):
    
    # Removing all the cells with zero values in it.i.e. all the rows have zero in it.
    
    df= df.loc[(df!=0).any(axis=1)]
    
    #df1 = df.loc[:,(df==0).mean()<0.8] ## removing all the columns with more than 80 % zeroes 
    
    selected_genes = ['ARL17B', 'NAIP', 'BCOR', 'XIST', 'TSC22D4', 'HEPACAM', 'FGF17', 'EZH1', 'FOXN2', 'NDUFAF6', 'CC2D1A', 'MARCKSL1', 'ZDHHC11B', 'PLXNB1', 'PLPPR2', 'AC090517.4', 'CDK18', 'LGI4', 'CHD7', 'RBMX', 'CDKL1', 'DNAJC7', 'SLC25A13', 'PER1', 'LPAR1', 'HIBADH', 'ZBED5', 'PTDSS2', 'ATG4B', 'PWWP2A', 'XRRA1', 'OTUD7B', 'SCD', 'UBE2Z', 'PIGQ']
    
    df1 = df[selected_genes]
    
    return df1




#!/usr/bin/env python
# coding: utf-8

# In[1]:


import os
import tensorflow
from tensorflow import keras


def load_model(df):
    
    dir_location = os.path.join(os.path.dirname(__file__), 'Model')
    
    #Load model
    model = keras.models.load_model(dir_location)
    
    return model


# In[ ]:







#!/usr/bin/env python
# coding: utf-8

# In[ ]:


import tensorflow 
from tensorflow import keras


def predict_patient(model,file):
    
    y_pred = model.predict(file)
    
    predictions = list(map(lambda x: 0 if x<0.5 else 1, y_pred))
    
    ones =0
    zeros =0
    
    for i in range(len(predictions)):
        if (predictions[i]==1):
            ones +=1
        else:
            zeros+=1
            
    #print("The number of ones are ", ones)
    #print("The number of zeros are ", zeros)
    #print("Total number of cells are ", len(predictions))
    print("Ones percentage are ", ones/len(predictions))
    print("Zeros percentage are ", zeros/len(predictions))
    
    op= ones/len(predictions) 
    zp= zeros/len(predictions)
    
    if(op>45):
        print("Alzheimer's patient detected")
        print("More the 45% diseased cells found")
    elif (zp>55):
        print("Normal patient found, No disease detected")




from setuptools import setup, find_packages


VERSION = '0.0.8'
DESCRIPTION = 'test file'
LONG_DESCRIPTION = 'A package that allows to test.'

# Setting up
setup(
    name="ThesisAZsc",
    version=VERSION,
    author="Aman and Akanksha",
    author_email="<mail@neuralnine.com>",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    packages=find_packages(),
    install_requires=['pandas','numpy','tensorflow','keras',],
    keywords=['python', 'Alzheimers', 'Diagnosis', 'Single cell', 'Genomics'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ],
    include_package_data=True,
)
